'use strict'
const Config = use('Config');

class GroupController {
    async get({response, auth}) {
        const user = await auth.getUser();
        const gitlab = use('gitlab')();
        gitlab.setOauth(user.oauth);
        const ret = [];
        let pages = 0;
        try {
            let url = '/groups';
            if (parseInt(Config.get('gitlab.group')) > 0) {
                url = `${url}?skip_groups[]=${parseInt(Config.get('gitlab.group'))}`;
            }
            const {data, headers} = await gitlab.get(url);
            for (let i = 0; i < data.length; i++) {
                const group = data[i];
                group.children = [];
                ret.push(group);
            }
            pages = parseInt(headers['x-total-pages']);
        }
        catch (error) {
            return gitlab.handleError(error, response);
        }
        if (pages > 1) {
            let page = 2;
            while (page <= pages) {
                try {
                    let url = `/groups?page=${page}`;
                    if (parseInt(Config.get('gitlab.group')) > 0) {
                        url = `${url}&skip_groups[]=${parseInt(Config.get('gitlab.group'))}`;
                    }
                    const {data, headers} = await gitlab.get(url);
                    for (let i = 0; i < data.length; i++) {
                        const group = data[i];
                        group.children = [];
                        ret.push(group);
                    }
                    pages = parseInt(headers['x-total-pages']);
                    page = parseInt(headers['x-next-page']);
                }
                catch (error) {
                    return gitlab.handleError(error, response);
                }
            }
        }
        return response.api(200, ret);
    }

    async getRepos({response, params, auth}) {
        const user = await auth.getUser();
        const gitlab = use('gitlab')();
        gitlab.setOauth(user.oauth);
        const ret = [];
        let pages = 0;
        try {
            let url = `/groups/${params.id}/projects`;
            const {data, headers} = await gitlab.get(url);
            for (let i = 0; i < data.length; i++) {
                const group = data[i];
                ret.push(group);
            }
            pages = parseInt(headers['x-total-pages']);
        }
        catch (error) {
            return gitlab.handleError(error, response);
        }
        if (pages > 1) {
            let page = 2;
            while (page <= pages) {
                try {
                    let url = `/groups/${params.id}/projects?page=${page}`;
                    const {data, headers} = await gitlab.get(url);
                    for (let i = 0; i < data.length; i++) {
                        const group = data[i];
                        ret.push(group);
                    }
                    pages = parseInt(headers['x-total-pages']);
                    page = parseInt(headers['x-next-page']);
                }
                catch (error) {
                    return gitlab.handleError(error, response);
                }
            }
        }
        return response.api(200, ret);
    }
}

module.exports = GroupController
