'use strict'
const Config = use('Config');
const User = use('App/Models/User');
const Cache = use('Cache');

class MeController {
    async login({request, response, auth}) {
        const gitlab = use('gitlab')();
        try {
            const {data} = await gitlab.getAccessToken({
                code: request.input('code'),
                client_id: gitlab.client_id,
                client_secret: gitlab.client_secret,
                grant_type: 'authorization_code',
                redirect_uri: `${request.header('origin')}/login/oauth/`,
            });
            gitlab.setOauth(data);
            const ur = await gitlab.get('/user');
            if (ur.data.state !== 'active') {
                return response.api(401, null, [{message: 'Your GitLab account is no longer authorized to login.'}])
            }
            if (!isNaN(Config.get('gitlab.group')) && parseInt(Config.get('gitlab.group')) > 0) {
                const gr = await gitlab.get(`/groups/${parseInt(Config.get('gitlab.group'))}/members/${ur.data.id}`);
                if (!gr.data.access_level || gr.data.access_level < 30) {
                    return response.api(401, null, [{message: 'You do not have permission to login with Hermes. Please contact your GitLab Administrator.'}])
                }
            }
            const user = await User.findOrCreate(
                {
                    user_id: ur.data.id
                },
                {
                    user_id: ur.data.id,
                }
            );
            user.oauth = data;
            await user.save();
            const body = await auth.generate(user);
            await Cache.put(body.token, true, 1440);
            return response.api(201, body);
        }
        catch (error) {
            return gitlab.handleError(error, response);
        }
    }

    async logout({response, auth}) {
        const apiToken = auth.getAuthHeader();
        const apiOTPToken = `totp_${auth.getAuthHeader()}`;
        await Cache.forget(apiToken);
        await Cache.forget(apiOTPToken);
        return response.api(200);
    }

    async whoami({response, auth}) {
        const user = await auth.getUser();
        const gitlab = use('gitlab')();
        gitlab.setOauth(user.oauth);
        try {
            const {data} = await gitlab.get('/user');
            return response.api(200, data);
        }
        catch (error) {
            return gitlab.handleError(error, response);
        }
    }
}

module.exports = MeController
