'use strict'
/** @typedef {import('@adonisjs/framework/src/Request')} Request */
/** @typedef {import('@adonisjs/framework/src/Response')} Response */
/** @typedef {import('@adonisjs/framework/src/View')} View */

class GitLab {
  /**
   * @param {object} ctx
   * @param {Request} ctx.request
   * @param {Function} next
   */
  async handle ({ request, auth, response }, next) {
    const user = await auth.getUser();
    const gitlab = use('gitlab')();
    const Config = use('Config');
    gitlab.setOauth(user.oauth);
    try {
        const {data} = await gitlab.get('/user');
        if ('active' !== data.state) {
          return response.api(401, null, [{message: 'Your GitLab User has been disabled. Please check with your GitLab Adminstrator.'}]);
        }
        if (Config.get('gitlab.group') > 0) {
          const gr = await gitlab.get(`/groups/${Config.get('gitlab.group')}/members/${data.id}`);
          if (!gr.data.access_level || gr.data.access_level < 30) {
              return response.api(401, null, [{message: 'You do not have permission to login with Hermes. Please contact your GitLab Administrator.'}])
          }
        }
        await next()   
    }
    catch (error) {
        return gitlab.handleError(error, response);
    }
  }
}

module.exports = GitLab
