'use strict'
/** @typedef {import('@adonisjs/framework/src/Request')} Request */
/** @typedef {import('@adonisjs/framework/src/Response')} Response */
/** @typedef {import('@adonisjs/framework/src/View')} View */

class GitlabJob {
  /**
   * @param {object} ctx
   * @param {Request} ctx.request
   * @param {Function} next
   */
  async handle ({ request, response }, next) {
    const BASH = use('bash');
    const bash = new BASH();
    const gitlab = use('gitlab')();
    const Config = use('Config');
    gitlab.setAuthMethod('pat');
    const auth = request.header('authorization');
    if ('string' !== typeof(auth) || !auth.includes('Basic ')) {
      bash.echo('You have not passed any authorization credentials');
      return response.bash(401, bash.toString(), [{message: 'Unauthorized'}]);
    }
    const b64 = auth.substr(6);
    const buff = Buffer.from(b64, 'base64');
    const basic = buff.toString('ascii');
    const authparts = basic.split(':');
    if (!Array.isArray(authparts) || authparts.length !== 2) {
      bash.echo('Invalid Authorization Credentials');
      return response.bash(401, bash.toString(), [{message: 'Unauthorized'}]);
    }
    const project = request.input('project');
    if (isNaN(project) || parseInt(project) == 0) {
      bash.echo('Invalid Project');
      return response.bash(404, bash.toString(), [{message: 'Project ID not Found'}]);
    }
    if ('gitlab-ci-token' == authparts[0]) {
      gitlab.setToken(Config.get('gitlab.token'));
      const uri = `/projects/${project}/jobs/${authparts[1]}`;
      try {
        const {data} = await gitlab.get(uri);
        if ('running' !== data.status) {
          return response.bash(403, null, [{message: `Forbidden: This script can only be fetched by a running CI/CD Job`}]);  
        }
        else {
          return await next();
        }
      }
      catch (error) {
        return response.bash(500, null, [{message: `Unable to fetch job status: ${error.toString()}`}]);
      }
    }
    else {
      gitlab.setToken(authparts[1]);
      const uri = `/projects/${project}/variables`;
      try {
        await gitlab.get(uri);
        return await next();
      }
      catch (error) {
        let code = 500;
        if (error.response) {
          code = error.response.status;
        }
        return response.bash(code, null, [{message: `Unable to Authenticate: ${error.toString()}`}]);
      }
    }
  }
}

module.exports = GitlabJob
