'use strict'
/** @typedef {import('@adonisjs/framework/src/Request')} Request */
/** @typedef {import('@adonisjs/framework/src/Response')} Response */
/** @typedef {import('@adonisjs/framework/src/View')} View */

const { validate, sanitize} = use('Validator');

class GitlabJobRequiredVar {
  /**
   * @param {object} ctx
   * @param {Request} ctx.request
   * @param {Function} next
   */
  async handle ({ request, response }, next) {
    const rules = {
      project: 'required|integer|min:1',
      environment: 'required|string',
    };
    const messages = {
      'project.required': 'You have not specified the project',
      'project.integer': 'The value of project must be the ID of the project in GitLab',
      'project.min': 'The value of the project cannot be less than 1',
      'environment.required': 'You have not specified the deployment environment',
      'environment.string': 'The environment name must be a string',
    }
    const validation = await validate(request.all(), rules, messages);
    if (validation.fails()) {
        return response.bash(400, null, validation.messages());
    }
    // call next to advance the request
    await next()
  }
}

module.exports = GitlabJobRequiredVar
