'use strict'

const Encryption = use('Encryption')

class Encryptable {
  register (Model, fields = []) {
    Model.addHook('beforeSave', async (item) => {
      for (let i = 0; i < fields.length; i++) {
        const field = fields[i];
        if (item.dirty[field]) {
          item[field] = Encryption.encrypt(item[field]);
        }
      }
    });
    Model.addHook('afterSave', async (item) => {
      for (let i = 0; i < fields.length; i++) {
        const field = fields[i];
        try {
          item[field] = Encryption.decrypt(item[field]);
        }
        catch (error) {
          item[field] = item[field];
        }
      }
    });
    Model.addHook('afterFind', async (item) => {
      for (let i = 0; i < fields.length; i++) {
        const field = fields[i];
        try {
          item[field] = Encryption.decrypt(item[field]);
        }
        catch (error) {
          item[field] = item[field];
        }
      }
    });
    Model.addHook('afterFetch', async items => {
        for (let item of items) {
          for (let i = 0; i < fields.length; i++) {
            const field = fields[i];
            try {
              item[field] = Encryption.decrypt(item[field]);
            }
            catch (error) {
              item[field] = item[field];
            }
          }
        }
    });
  }
}

module.exports = Encryptable
