'use strict'

class Serializable {
  register (Model, fields = []) {
    Model.addHook('beforeSave', async (item) => {
      for (let i = 0; i < fields.length; i++) {
        const field = fields[i];
        if (item.dirty[field]) {
          item[field] = JSON.stringify(item[field]);
        }
      }
    });
    Model.addHook('afterSave', async (item) => {
      for (let i = 0; i < fields.length; i++) {
        const field = fields[i];
        if ('string' === typeof(item[field])) {
          try {
            item[field] = JSON.parse(item[field]);
          }
          catch (error) {
            item[field] = item[field].toString();
          }
        }
      }
    });
    Model.addHook('afterFind', async (item) => {
      for (let i = 0; i < fields.length; i++) {
        const field = fields[i];
        if ('string' === typeof(item[field])) {
          try {
            item[field] = JSON.parse(item[field]);
          }
          catch (error) {
            item[field] = item[field].toString();
          }
        }
      }
    });
    Model.addHook('afterFetch', async items => {
        for (let item of items) {
          for (let i = 0; i < fields.length; i++) {
            const field = fields[i];
            if ('string' === typeof(item[field])) {
              try {
                item[field] = JSON.parse(item[field]);
              }
              catch (error) {
                item[field] = item[field].toString();
              }
            }
          }
        }
    });
  }
}

module.exports = Serializable
