'use strict'

/** @type {import('@adonisjs/framework/src/Hash')} */
const Hash = use('Hash')

/** @type {typeof import('@adonisjs/lucid/src/Lucid/Model')} */
const Model = use('Model')

class User extends Model {
  static boot () {
    super.boot()
    this.addHook('beforeSave', async (item) => {
      if (item.dirty.oauth) {
          item.oauth = JSON.stringify(item.oauth);
      }
    });
    this.addHook('afterSave', async (item) => {
      if ('string' === typeof(item.oauth)) {
          item.oauth = JSON.parse(item.oauth);
      }
    });
    this.addHook('afterFind', async (item) => {
      if ('string' === typeof(item.oauth)) {
          item.oauth = JSON.parse(item.oauth);
      }
    });
    this.addHook('afterFetch', async items => {
      for (let item of items) {
          if ('string' === typeof(item.oauth)) {
              item.oauth = JSON.parse(item.oauth);
          }
      }
    });
  }

  /**
   * A relationship on tokens is required for auth to
   * work. Since features like `refreshTokens` or
   * `rememberToken` will be saved inside the
   * tokens table.
   *
   * @method tokens
   *
   * @return {Object}
   */
  tokens () {
    return this.hasMany('App/Models/Token')
  }
}

module.exports = User
