const Server = use('Server');
const io = require('socket.io')(Server.getInstance());
const Cache = use('Cache');

io.of('/admin').use(async(socket, next) => {
    if ('object' === typeof(socket.handshake.query) && null !== socket.handshake.query && 'string' === typeof(socket.handshake.query.jwt)) {
        const apiToken = socket.handshake.query.jwt;
        const status = await Cache.get(apiToken);
        if ( ('string' === typeof(status) && 'true' !== status) || ('boolean' === typeof(status) && true !== status ) || ['string', 'boolean'].indexOf(typeof(status)) === -1) {
            return next(new Error('Invalid or Missing JWT'));
        }
        return next();
    }
    else {
        return next(new Error('Invalid or Missing JWT'));
    }
});

class SocketServer {
    constructor(io) {
        this.io = io;
        this.sockets = new Map();
        this.events = new Map();
        this.io.of('/admin').on('connection', (socket) => {
            this.sockets.set(socket.id, socket);
            const version = use('version');
            socket.emit('connected', version);
            socket.emit('version', version);
            // console.log(`Added socket ${socket.id} to the list of sockets`);
            socket.on('disconnect', () => {
                this.sockets.delete(socket.id);
                // console.log(`Removed socket ${socket.id} from the list of sockets`);
            });
        });
    }

    on(event, callback) {
        if (!this.events.has(event)) {
            this.events.set(event, new Map());
        }
        const sid = shortid.generate();
        this.events.get(event).set(sid, callback);
        return sid;
    }

    off(event, sid) {
        if (!this.events.has(event)) {
            return true;
        }
        if ('undefined' == typeof(sid)) {
            this.events.delete(event);
            return true;
        }
        else {
            this.events.get(event).delete(sid);
            return true;
        }
    }

    async _trigger(event, data, sync) {
        if (this.events.has(event)) {
            this.events.get(event).forEach(async(cb, sid) => {
                if (true == this.debug) {
                    console.log(`Calling Callback ${sid} for event ${event} with data ${JSON.stringify(data)}`);
                }
                if (true == sync) {
                    await cb(data);
                }
                else {
                    cb(data)
                }
            });
        }
    }

    broadcast(event, data) {
        if ('function' == typeof(process.send)) {
            process.send({
                event,
                data
            });
        } else {
            this.sockets.forEach((socket, socketId) => {
                socket.emit(event, data);
            })
        }
    }
}

const s = new SocketServer(io);

module.exports = s;