'use strict'

const Env = use('Env')
const Helpers = use('Helpers')

module.exports = {

  /*
  |--------------------------------------------------------------------------
  | Default Cache Store
  |--------------------------------------------------------------------------
  |
  | This option controls the default cache store that gets used while
  | using this caching library. This store is used when another is
  | not explicitly specified when executing a given caching function.
  |
  */

  default: Env.get('CACHE_STORE', 'object'),

  /*
  |--------------------------------------------------------------------------
  | Cache Stores
  |--------------------------------------------------------------------------
  |
  | Here you may define all of the cache "stores" for your application as
  | well as their drivers. You may even define multiple stores for the
  | same cache driver to group types of items stored in your caches.
  |
  | Supported drivers: "object", "database", "redis"
  |
  | Hint: Use "null" driver for disabling caching
  | Warning: Use the "object" driver only for development, it does not have a garbage collector.
  |
  */

  stores: {

    object: {
      driver: 'object'
    },

    database: {
      driver: 'database',
      table: 'cache',
      connection: 'sqlite'
    },

    redis: {
      driver: 'redis',
      connection: 'local'
    },

    null: {
      driver: 'null'
    }

  },

  /*
  |--------------------------------------------------------------------------
  | Cache Key Prefix
  |--------------------------------------------------------------------------
  |
  | When utilizing a RAM based store, there might be other applications
  | utilizing the same cache. So, we'll specify a value to get prefixed
  | to all our keys so we can avoid collisions.
  |
  */

  prefix: 'adonis'

}
