const escape_quotes = require('escape-quotes');
const qs = require('qs');

class BashScript {
    constructor() {
        this.commands = [];   
    }

    send(something) {
        if ('string' === typeof(something)) {
            this.commands.push(something);
        }
    }

    echo(text) {
        this.send(`echo "${escape_quotes(text, '"')}"`);
    }

    export(key, val) {
        this.send(`export ${escape_quotes(key, '"')}="${escape_quotes(val, '"')}"`);
    }

    escape(val) {
        return escape_quotes(val, '"');
    }

    clear() {
        this.commands = [];
    }

    toString() {
        let payload = '';
        for (let i = 0; i < this.commands.length; i++) {
            const cmd = this.commands[i];
            payload += `${cmd}\n`;
        }
        return payload;
    }

    inspect() {
        return this.toString();
    }

    webhook(hook) {
        this.echo('####################################');
        this.echo(`## Reponse from Webhook "${hook.name}"`);
        this.echo('####################################');
        const args = [
            'curl', '-X', hook.method.toUpperCase(), '-S'
        ]
        if (('string' == typeof(hook.auth_username) && hook.auth_username.length > 0) || ('string' == typeof(hook.auth_password) && hook.auth_password.length > 0)) {
            args.push(`--user "${hook.auth_username}":"${hook.auth_password}"`);
        }
        if (false == hook.validate_ssl) {
            args.push('--insecure');
        }
        args.push(`"${hook.url}"`);
        if ('string' == typeof(hook.headers) && hook.headers.length > 0) {
            const headers = hook.headers.split("\n").map((row) => {
                row = `-H "${this.escape(row)}"`;
                return row;
            });
            for (let i = 0; i < headers.length; i++) {
                const header = headers[i];
                args.push(header);
            }
        }
        const vars = [
            "DEPLOY_USERNAME",
            "DEPLOY_HOST",
            "DEPLOY_PORT",
            "DEPLOY_AUTH_METHOD",
            "DEPLOY_PASSWORD",
            "DEPLOY_KEY",
            "DEPLOY_PATH",
            "DEPLOY_METHOD",
            "DEPLOY_REMOTE_OWNER",
            "DEPLOY_REMOTE_GROUP",
        ];
        if (['post', 'put', 'patch'].indexOf(hook.method) > -1 && 'string' == typeof(hook.body) && hook.body.length > 0) {
            switch (hook.body_type) {
                case 'json':
                    try {
                        const obj = JSON.parse(hook.body);
                        let body = qs.stringify(obj);
                        for (let i = 0; i < vars.length; i++) {
                            const varkey = vars[i];
                            const urlkey = qs.stringify({key: `$${varkey}`}).replace('key=', '');
                            if (body.includes(urlkey)) {
                                body = body.replace(urlkey, `$${varkey}`);
                            }
                        }
                        args.push(`-d "${this.escape(body)}"`);
                    }
                    catch (error) {
                        // bad JSON
                    }
                    break;

                case 'plain':
                    args.push(`-d "${this.escape(hook.body)}"`);
                    break;

                default:
                    try {
                        const obj = qs.parse(hook.body)
                        let body = qs.stringify(obj);
                        for (let i = 0; i < vars.length; i++) {
                            const varkey = vars[i];
                            const urlkey = qs.stringify({key: `$${varkey}`}).replace('key=', '');
                            if (body.includes(urlkey)) {
                                body = body.replace(urlkey, `$${varkey}`);
                            }
                        }
                        args.push(`-d "${this.escape(body)}"`);
                    }
                    catch (error) {
                        // bad query
                    }
                    break;
            }
        }
        this.send(args.join(' '));
    }

    runningPipelineCheck(request, req) {
        req.ref = 'CI_COMMIT_REF_NAME';
        req.pipeline = 'CI_PIPELINE_ID';
        this.echo(`Checking for already running pipelines`);
        const Config = use('Config');
        const headers = request.headers();
        let protocol = 'http';
        // let host = headers.host;
        let host = '';
        if ('string' == typeof(headers.http_cf_visitor)) {
            try {
                const visitor = JSON.parse(headers.http_cf_visitor)
                protocol = visitor.scheme;
            } catch (error) {
                // not parsable
            }
        }
        else if ('undefined' !== typeof(headers.https) || 'https' == headers.http_x_forwarded_proto ) {
            protocol = 'https';
        }
        if ('string' == typeof(headers.host)) {
            host = headers.host;
        }
        else {
            host = Config.get('app.url').replace('http://', '').replace('https://', '');
        }
        const url = `${protocol}://${host}/cd/check-pipeline?${qs.stringify(req)}`.replace('CI_COMMIT_REF_NAME', '$CI_COMMIT_REF_NAME').replace('CI_PIPELINE_ID', '$CI_PIPELINE_ID');
        const auth = request.header('authorization');
        const b64 = auth.substr(6);
        const buff = Buffer.from(b64, 'base64');
        const basic = buff.toString('ascii');
        const authparts = basic.split(':');
        let send;
        if ('true' == request.input('osx')) {
            send = `source /dev/stdin <<<"$(curl -s --user "${authparts[0]}":"${authparts[1]}" "${url}")"`;
        }
        else {
            send = `source <(curl -s --user "${authparts[0]}":"${authparts[1]}" "${url}")`;
        }
        this.send(send);
    }

    deployRsync(c) {
        this.echo('Checking Requirements for Deployment using rsync');
        let rsync_cmd;
        let remote_cmd_pattern;
        switch(c.authmethod) {
            case 'password':
                this.send('if which sshpass > /dev/null');
                this.send(' then');
                this.send('     echo "sshpass is installed"');
                this.send(' else');
                this.send('     echo "sshpass is not installed. script is stopping"');
                this.send('     exit 1');
                this.send('fi');
                rsync_cmd = `sshpass -p "$DEPLOY_PASSWORD" ssh -o StrictHostKeyChecking=no -o ServerAliveInterval=30`;
                remote_cmd_pattern = 'sshpass -p "$DEPLOY_PASSWORD" ssh -o StrictHostKeyChecking=no -o ServerAliveInterval=30 "$DEPLOY_USERNAME@$DEPLOY_HOST" -p "$DEPLOY_PORT" "echo $DEPLOY_PASSWORD | sudo -S su -c \'%s\'"';
                break;

            case 'pem':
                this.send('if which ssh > /dev/null');
                this.send(' then');
                this.send('     echo "ssh is installed"');
                this.send(' else');
                this.send('     echo "ssh is not installed. script is stopping"');
                this.send('     exit 1');
                this.send('fi');
                rsync_cmd = `ssh -i /tmp/deploykey.pem -o StrictHostKeyChecking=no -o ServerAliveInterval=30`;
                remote_cmd_pattern = 'ssh -i /tmp/deploykey.pem -o StrictHostKeyChecking=no -o ServerAliveInterval=30 "$DEPLOY_USERNAME@$DEPLOY_HOST" -p "$DEPLOY_PORT" "sudo su -c \'%s\'"';
                break;
        }
        if ('string' == typeof(c.predeploy) && c.predeploy.length > 0) {
            this.echo('##################################################');
            this.echo('### Running Pre-Syncronization Remote Commands ###');
            this.echo('##################################################');
            const cmds = c.predeploy.split("\n").map((row) => {
                row = row.trim();
                row = escape_quotes(row, "'");
                row = escape_quotes(row, "$");
                row = row.replace('$DEPLOY_PASSWORD', 'DEPLOY_SENSATIVE_VALUE').replace('$DEPLOY_KEY', 'DEPLOY_SENSATIVE_VALUE');
                row = remote_cmd_pattern.replace('%s', row);
                return row;
            });
            for (let i = 0; i < cmds.length; i++) {
                const cmd = cmds[i];
                this.send(cmd);
            }
        }
        else {
            this.echo('No Pre-Syncronization Remote Commands to run');
        }
        this.echo('######################################');
        this.echo('### Syncronizing Files with rsync ###');
        this.echo('#####################################');
        this.echo('Updating Deployment Directory Ownership to allow Sync');
        this.send(remote_cmd_pattern.replace('%s', 'chown "$DEPLOY_USERNAME":"$DEPLOY_REMOTE_GROUP" "$DEPLOY_PATH" -R'));
        const rsync_cmd_args = ['rsync', '-rog', '--delete', '--compress', '--super', '--fake-super', '--links', '--owner="$DEPLOY_REMOTE_OWNER"', '--group="$DEPLOY_REMOTE_GROUP"', '--human-readable', '--update', '--progress', `--rsh="${rsync_cmd}"`];
        if (true == c.additional.cvsExclude) {
            rsync_cmd_args.push('--cvs-exclude');
            rsync_cmd_args.push('--include "core"');
        }
        if (true == c.additional.useRsyncIgnore) {
            rsync_cmd_args.push('--exclude-from=".rsyncignore"');
        }
        rsync_cmd_args.push('$PWD/');
        rsync_cmd_args.push('"$DEPLOY_USERNAME@$DEPLOY_HOST:$DEPLOY_PATH"');
        this.echo('Running rsync');
        this.send(rsync_cmd_args.join(' '));
        this.echo('Updating Deployment Directory Ownership to Remote Owner');
        this.send(remote_cmd_pattern.replace('%s', 'chown "$DEPLOY_REMOTE_OWNER":"$DEPLOY_REMOTE_GROUP" "$DEPLOY_PATH" -R'));
        this.echo('rsync finished');
        if ('string' == typeof(c.postdeploy) && c.postdeploy.length > 0) {
            this.echo('###################################################');
            this.echo('### Running Post-Syncronization Remote Commands ###');
            this.echo('###################################################');
            const cmds = c.postdeploy.split("\n").map((row) => {
                row = row.trim();
                row = escape_quotes(row, '"');
                row = row.replace('$DEPLOY_PASSWORD', 'DEPLOY_SENSATIVE_VALUE').replace('$DEPLOY_KEY', 'DEPLOY_SENSATIVE_VALUE');
                row = remote_cmd_pattern.replace('%s', row);
                return row;
            });
            for (let i = 0; i < cmds.length; i++) {
                const cmd = cmds[i];
                this.send(cmd);
            }
        }
        else {
            this.echo('No Post-Syncronization Remote Commands to run');
        }
    }
}

module.exports = BashScript;