import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router);

export default new Router({
    mode: 'history',
    scrollBehavior() {
        return window.scrollTo({ top: 0, behavior: 'smooth' });
    },
    routes: [
        {
            path: '/',
            name: 'dashboard',
            component: () => import('../pages/system/dashboard'), // jshint ignore:line
            meta: {
                title: 'Dashboard',
                breadcrumbs: [],
            },
        },
        {
            path: '/repositories/:id',
            name: 'repository-index',
            component: () => import('../pages/repositories/index'), // jshint ignore:line
            meta: {
                title: 'Repository #{{$route.params.id}}',
                breadcrumbs: [
                    {
                        to: '/',
                        display: 'Dashboard',
                    },
                    {
                        to: null,
                        display: 'Repository #{{$route.params.id}}',
                    }
                ],
            },
        },
        {
            path: '/repositories/:repository/webhooks/:id',
            name: 'edit-general-webhook',
            component: () => import('../pages/webhooks/edit'), // jshint ignore:line
            meta: {
                title: 'Repository #{{$route.params.repository}} Webhook',
                breadcrumbs: [
                    {
                        to: '/',
                        display: 'Dashboard',
                    },
                    {
                        to: '/repositories/{{$route.params.repository}}',
                        display: 'Repository #{{$route.params.repository}}',
                    },
                    {
                        to: null,
                        display: 'Manage Webhook Repository #{{$route.params.repository}}',
                    }
                ],
            },
        },
        {
            path: '/repositories/:repository/credentials/:id',
            name: 'repository-edit',
            component: () => import('../pages/repositories/edit'), // jshint ignore:line
            meta: {
                title: 'Manage Repository #{{$route.params.repository}} Credentials #{{$route.params.id}}',
                breadcrumbs: [
                    {
                        to: '/',
                        display: 'Dashboard',
                    },
                    {
                        to: '/repositories/{{$route.params.repository}}',
                        display: 'Repository #{{$route.params.repository}}',
                    },
                    {
                        to: null,
                        display: 'Manage Credentials for Repository #{{$route.params.repository}}',
                    }
                ],
            },
        },
        {
            path: '/repositories/:repository/credentials/:credentials/webhooks/:id',
            name: 'edit-credentials-webhook',
            component: () => import('../pages/webhooks/edit'), // jshint ignore:line
            meta: {
                title: 'Manage Repository #{{$route.params.repository}} Credentials #{{$route.params.id}} Webhook',
                breadcrumbs: [
                    {
                        to: '/',
                        display: 'Dashboard',
                    },
                    {
                        to: '/repositories/{{$route.params.repository}}',
                        display: 'Repository #{{$route.params.repository}}',
                    },
                    {
                        to: '/repositories/{{$route.params.repository}}/credentials/{{$route.params.credentials}}',
                        display: 'Manage Credentials for Repository #{{$route.params.repository}}',
                    },
                    {
                        to: null,
                        display: 'Manage Webhook for Repository #{{$route.params.repository}} Credentials #{{$route.params.credentials}}',
                    }
                ],
            },
        },
        {
            path: '*',
            name: 'four-oh-four',
            component: () => import('../pages/system/404'), // jshint ignore:line
            meta: {
                title: 'Page not Found',
                breadcrumbs: [
                    {
                        to: '/',
                        display: 'Dashboard',
                    },
                    {
                        to: null,
                        display: 'Page not Found',
                    }
                ],
            },
        },
    ]
})
