#!/bin/bash
echo "Welcome:"
whoami
ENVFILE=/home/hermes/.env
NODEMODULEFILES=/home/hermes/node_modules
FINALENV="/home/hermes/.env.${NODE_ENV}"
function create_env_file {
    if [ -f "$ENVFILE" ]; then
        > /home/hermes/.env
    else 
        touch /home/hermes/.env
    fi
    echo "HOST=0.0.0.0" >> /home/hermes/.env
    echo "PORT=3333" >> /home/hermes/.env
    echo "NODE_ENV=${NODE_ENV}" >> /home/hermes/.env
    echo "APP_URL=http://\${HOST}:\${PORT}" >> /home/hermes/.env
    echo "CACHE_VIEWS=false" >> /home/hermes/.env
    echo "CACHE_STORE=${CACHE_STORE}" >> /home/hermes/.env
    echo "APP_KEY=${APP_KEY}" >> /home/hermes/.env
    echo "APP_DEBUG=${APP_DEBUG}" >> /home/hermes/.env
    echo "IS_DEMO=${IS_DEMO}" >> /home/hermes/.env
    echo "DB_CONNECTION=${DB_CONNECTION}" >> /home/hermes/.env
    echo "DB_HOST=${DB_HOST}" >> /home/hermes/.env
    echo "DB_PORT=${DB_PORT}" >> /home/hermes/.env
    echo "DB_USER=${DB_USER}" >> /home/hermes/.env
    echo "DB_PASSWORD=${DB_PASSWORD}" >> /home/hermes/.env
    echo "DB_DATABASE=${DB_DATABASE}" >> /home/hermes/.env
    echo "DB_SSL=${DB_SSL}" >> /home/hermes/.env
    echo "REDIS_HOST=${REDIS_HOST}" >> /home/hermes/.env
    echo "REDIS_PORT=${REDIS_PORT}" >> /home/hermes/.env
    echo "REDIS_PASSWORD=${REDIS_PASSWORD}" >> /home/hermes/.env
    echo "REDIS_DB_ID=${REDIS_DB_ID}" >> /home/hermes/.env
    echo "REDIS_PREFIX=${REDIS_PREFIX}" >> /home/hermes/.env
    echo "SESSION_DRIVER=cookie" >> /home/hermes/.env
    echo "HASH_DRIVER=bcrypt" >> /home/hermes/.env
    echo "GITLAB_HOST=${GITLAB_HOST}" >> /home/hermes/.env
    echo "GITLAB_APP_ID=${GITLAB_APP_ID}" >> /home/hermes/.env
    echo "GITLAB_APP_SECRET=${GITLAB_APP_SECRET}" >> /home/hermes/.env
    echo "GITLAB_ADMIN_TOKEN=${GITLAB_ADMIN_TOKEN}" >> /home/hermes/.env
    echo "GITLAB_CREDENTIALS_GROUP=${GITLAB_CREDENTIALS_GROUP}" >> /home/hermes/.env
}

echo "Starting Pre-flight Check"
if which node > /dev/null
    then
        echo "Node JS Version:"
        node -v
        echo "NPM Version:"
        npm -v
    else
        echo "NodeJS is not installed"
        exit 1
fi
if which adonis > /dev/null
    then
        echo "Adonis is installed globally"
    else
        echo "Adonis is not installed globally"
        exit 1
fi
if which nginx > /dev/null
    then
        echo "nginx version"
        nginx -v
        nginx -t
    else
        echo "nginx not installed"
        exit 1
fi
echo "Creating Environment File"
create_env_file
export $(egrep -v '^#' .env | xargs)
if [ -z "$NODE_ENV" ]
    then
        echo "Required Environmental Variable NODE_ENV is empty"
        exit 1
fi

if [ -z "$CACHE_STORE" ]
    then
        echo "Required Environmental Variable CACHE_STORE is empty"
        exit 1
fi

if [ -z "$APP_KEY" ]
    then
        echo "App Key not provided or empty. Generating a new App Key"
        adonis key:generate --force
fi

if [ -z "$APP_DEBUG" ]
    then
        echo "Required Environmental Variable APP_DEBUG is empty"
        exit 1
fi

if [ -z "$DB_CONNECTION" ]
    then
        echo "Required Environmental Variable DB_CONNECTION is empty"
        exit 1
fi

if [ -z "$DB_HOST" ]
    then
        echo "Required Environmental Variable DB_HOST is empty"
        exit 1
fi

if [ -z "$DB_PORT" ]
    then
        echo "Required Environmental Variable DB_PORT is empty"
        exit 1
fi

if [ -z "$DB_DATABASE" ]
    then
        echo "Required Environmental Variable DB_DATABASE is empty"
        exit 1
fi

if [ -z "$REDIS_HOST" ]
    then
        echo "Required Environmental Variable REDIS_HOST is empty"
        exit 1
fi

if [ -z "$REDIS_PORT" ]
    then
        echo "Required Environmental Variable REDIS_PORT is empty"
        exit 1
fi

if [ -z "$REDIS_DB_ID" ]
    then
        echo "Required Environmental Variable REDIS_DB_ID is empty"
        exit 1
fi

if [ -z "$GITLAB_HOST" ]
    then
        echo "Required Environmental Variable GITLAB_HOST is empty"
        exit 1
fi

if [ -z "$GITLAB_APP_ID" ]
    then
        echo "Required Environmental Variable GITLAB_APP_ID is empty"
        exit 1
fi

if [ -z "$GITLAB_APP_SECRET" ]
    then
        echo "Required Environmental Variable GITLAB_APP_SECRET is empty"
        exit 1
fi

if [ -z "$GITLAB_ADMIN_TOKEN" ]
    then
        echo "Required Environmental Variable GITLAB_ADMIN_TOKEN is empty"
        exit 1
fi

export $(egrep -v '^#' .env | xargs)
echo "Environmental Configuration:"
cat /home/hermes/.env
echo ""
echo "Running Database Migrations"
adonis migration:run --force
echo "Starting nginx"
service nginx start
echo "Starting Hermes"
adonis serve