'use strict'

/*
|--------------------------------------------------------------------------
| Routes
|--------------------------------------------------------------------------
|
| Http routes are entry points to your web application. You can create
| routes for different URL's and bind Controller actions to them.
|
| A complete guide on routing is available here.
| http://adonisjs.com/docs/4.1/routing
|
*/

/** @type {typeof import('@adonisjs/framework/src/Route/Manager')} */
const Route = use('Route')
const Helpers = use('Helpers');

Route.group(() => {
    Route.get('/:id/info', 'RepositoryController.info');
    Route.get('/:id/badges', 'RepositoryController.badges');
    Route.get('/:id/readme', 'RepositoryController.readme');
    Route.get('/:id/credentials', 'RepositoryController.credentials');
    Route.get('/:id/credentials/:cid', 'RepositoryController.getCredentials');
    Route.post('/:id/credentials/', 'RepositoryController.storeCredentials');
    Route.put('/:id/credentials/:cid', 'RepositoryController.storeCredentials');
    Route.post('/:id/credentials/:cid/activation', 'RepositoryController.storeCredentialActivation');
    Route.get('/:id/webhooks', 'WebhookController.list');
    Route.get('/:id/credentials/:cid/webhooks', 'WebhookController.list');
    Route.post('/:id/webhooks', 'WebhookController.store');
    Route.post('/:id/credentials/:cid/webhooks', 'WebhookController.store');
    Route.get('/:id/webhooks/:wid', 'WebhookController.view');
    Route.get('/:id/credentials/:cid/webhooks/:wid', 'WebhookController.view');
    Route.put('/:id/webhooks/:wid', 'WebhookController.store');
    Route.put('/:id/credentials/:cid/webhooks/:wid', 'WebhookController.store');
    Route.post('/:id/webhooks/:wid/activation', 'WebhookController.setActivation');
    Route.post('/:id/credentials/:cid/webhooks/:wid/activation', 'WebhookController.setActivation');
}).prefix('api/v1/repositories').middleware(['auth', 'jwtauth', 'gitlab']);

Route.group(() => {
    Route.get('/', 'GroupController.get');
    Route.get('/:id/repositories', 'GroupController.getRepos');
}).prefix('api/v1/groups').middleware(['auth', 'jwtauth', 'gitlab']);

Route.group(() => {
    Route.get('/', 'MeController.whoami').middleware(['auth', 'jwtauth']);
    Route.post('/', 'MeController.login');
    Route.delete('/', 'MeController.logout').middleware(['auth', 'jwtauth']);
}).prefix('api/v1/me');

Route.group(() => {
    Route.get('/', 'SystemController.getSystem');
}).prefix('api/v1/system');

Route.group(() => {
    Route.any('*', 'SystemController.handleFourOhFour');
}).prefix('api/v1');

Route.group(() => {
    Route.get('/deploy', 'GitlabScriptController.deploy').middleware(['cdvars']);
    Route.get('/check-pipeline', 'GitlabScriptController.checkPipeline').middleware(['cdvars']);
    Route.get('/end', 'GitlabScriptController.end').middleware(['cdvars']);
    Route.get('/start', 'GitlabScriptController.start').middleware(['cdvars']);
    Route.any('*', 'GitlabScriptController.handleFourOhFour');
}).prefix('cd').middleware(['cd']);

/**
 * Catch All for everything else
 */
Route.any('*', ({request, response}) => {
    return response.download(Helpers.publicPath('index.html'));
});