'use strict'

const { test, trait } = use('Test/Suite')('Test Credential Listing, Creation and Modification')

trait('Test/ApiClient')

test('Get Empty List of Credentials for Repository 9', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.get('/api/v1/repositories/9/credentials').header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(200);
  gr.assertJSONSubset({ status: 'SUCCESS', code: 200, body: { total: 0, perPage: 10, page: 1, lastPage: 0, data: []}});
});

test('Add inactive credentials for repository 9 with environment "production" method "none"', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.post('/api/v1/repositories/9/credentials').header('Authorization', `Bearer ${response.body.body.token}`).send({
    environment: 'production',
    active: false,
    user: '',
    host: '',
    port: 22,
    authmethod: '',
    password: '',
    pemkey: '',
    method: 'none',
    path: '',
    suser: '',
    sgroup: '',
    predeploy: '',
    postdeploy: '',
    additional: {},
  }).end();
  gr.assertStatus(201);
  gr.assertJSONSubset({"status":"SUCCESS","code":201,"body":{"environment":"production","active":false,"user":null,"host":null,"port":22,"authmethod":"","password":null,"pemkey":null,"method":"none","path":null,"suser":null,"sgroup":null,"predeploy":"","postdeploy":"","additional":{},"gitlab_repository_id":9,"id":1}});
});

test('Get a List of Credentials for Repository 9', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.get('/api/v1/repositories/9/credentials').header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(200);
  // console.log(JSON.stringify(gr.body));
  gr.assertJSONSubset({"status":"SUCCESS","code":200,"body":{"total":1,"perPage":10,"page":1,"lastPage":1,"data":[{"id":1,"active":false,"environment":"production","host":null,"method":"none","authmethod":""}]}});
});

test('Activate credentials #1 for repository 9 with environment "production" method "none"', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.put('/api/v1/repositories/9/credentials/1').header('Authorization', `Bearer ${response.body.body.token}`).send({
    environment: 'production',
    active: true,
    user: '',
    host: '',
    port: 22,
    authmethod: '',
    password: '',
    pemkey: '',
    method: 'none',
    path: '',
    suser: '',
    sgroup: '',
    predeploy: '',
    postdeploy: '',
    additional: {},
  }).end();
  gr.assertStatus(201);
  // console.log(JSON.stringify(gr.body));
  gr.assertJSONSubset({"status":"SUCCESS","code":201,"body":{"id":1,"environment":"production","active":true,"user":null,"host":null,"port":22,"authmethod":"","password":null,"pemkey":null,"method":"none","path":null,"suser":null,"sgroup":null,"predeploy":"","postdeploy":"","additional":{},"gitlab_repository_id":9}});
});

test('Add active credentials for repository 9 with environment "production" method "rsync"', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.post('/api/v1/repositories/9/credentials').header('Authorization', `Bearer ${response.body.body.token}`).send({
    environment: 'production',
    active: true,
    user: 'root',
    host: 'ssh-server',
    port: 22,
    authmethod: 'password',
    password: 'root',
    pemkey: '',
    method: 'rsync',
    path: '/home/rsync',
    suser: 'root',
    sgroup: 'root',
    predeploy: '',
    postdeploy: 'ls -la /home/rsync',
    additional: {},
  }).end();
  gr.assertStatus(201);
  // console.log(JSON.stringify(gr.body));
  gr.assertJSONSubset({"status":"SUCCESS","code":201,"body":{"environment":"production","active":true,"user":"root","host":"ssh-server","port":22,"authmethod":"password","password":"root","pemkey":null,"method":"rsync","path":"/home/rsync","suser":"root","sgroup":"root","predeploy":"","postdeploy":"ls -la /home/rsync","additional":{},"gitlab_repository_id":9,"id":2}});
});

test('Get a final of Credentials for Repository 9', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.get('/api/v1/repositories/9/credentials').header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(200);
  // console.log(JSON.stringify(gr.body));
  gr.assertJSONSubset({"status":"SUCCESS","code":200,"body":{"total":2,"perPage":10,"page":1,"lastPage":1,"data":[{"id":1,"active":true,"environment":"production","host":null,"method":"none","authmethod":""},{"id":2,"active":true,"environment":"production","host":"ssh-server","method":"rsync","authmethod":"password"}]}});
});