'use strict'

const { test, trait } = use('Test/Suite')('List Groups')

trait('Test/ApiClient')

test('List all Groups associated with a User', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.get('/api/v1/groups').header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(200);
  gr.assertJSONSubset({
    status: 'SUCCESS',
    code: 200,
    body: [
      {
        "id": 1,
        "name": "Foobar Group",
        "path": "foo-bar",
        "description": "An interesting group",
        "visibility": "public",
        "share_with_group_lock": false,
        "require_two_factor_authentication": false,
        "two_factor_grace_period": 48,
        "project_creation_level": "developer",
        "auto_devops_enabled": null,
        "subgroup_creation_level": "owner",
        "emails_disabled": null,
        "lfs_enabled": true,
        "avatar_url": "https://www.gravatar.com/avatar/XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX",
        "web_url": "http://localhost:3000/groups/foo-bar",
        "request_access_enabled": false,
        "full_name": "Foobar Group",
        "full_path": "foo-bar",
        "file_template_project_id": 1,
        "parent_id": null
      }
    ]
  });
})
