'use strict'

const { test, trait } = use('Test/Suite')('Login')

trait('Test/ApiClient')

test('Login, Receive JWT and get Personal Information', async ({ assert, client }) => {
  // assert.equal(2 + 2, 4)
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const meresponse = await client.get('/api/v1/me').header('Authorization', `Bearer ${response.body.body.token}`).end();
  meresponse.assertStatus(200);
  meresponse.assertJSONSubset({
    status: 'SUCCESS',
    code: 200,
    body: {
      "id": 1,
      "username": "john_smith",
      "email": "john@example.com",
      "name": "John Smith",
      "state": "active",
      "avatar_url": "https://www.gravatar.com/avatar/XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX",
      "web_url": "https://www.gravatar.com/avatar/XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX",
      "created_at": "2012-05-23T08:00:58Z",
      "bio": null,
      "location": null,
      "public_email": "john@example.com",
      "skype": "",
      "linkedin": "",
      "twitter": "",
      "website_url": "",
      "organization": "",
      "last_sign_in_at": "2012-06-01T11:41:01Z",
      "confirmed_at": "2012-05-23T09:05:22Z",
      "theme_id": 1,
      "last_activity_on": "2012-05-23",
      "color_scheme_id": 2,
      "projects_limit": 100,
      "current_sign_in_at": "2012-06-02T06:36:55Z",
      "identities": [
          {"provider": "github", "extern_uid": "2435223452345"},
          {"provider": "bitbucket", "extern_uid": "john_smith"},
          {"provider": "google_oauth2", "extern_uid": "8776128412476123468721346"}
      ],
      "can_create_group": true,
      "can_create_project": true,
      "two_factor_enabled": true,
      "external": false,
      "private_profile": false
    } 
  });
})
