'use strict'

const { test, trait } = use('Test/Suite')('List Group Repositories')

trait('Test/ApiClient')

test('List all Repositories under a Group', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.get('/api/v1/groups/1/repositories').header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(200);
  gr.assertJSONSubset({
    status: 'SUCCESS',
    code: 200,
    body: [
      {
        "id": 9,
        "description": "foo",
        "default_branch": "master",
        "tag_list": [],
        "archived": false,
        "visibility": "internal",
        "ssh_url_to_repo": "git@gitlab.example.com/html5-boilerplate.git",
        "http_url_to_repo": "https://gitlab.jak.guru/public-libs/hermes.git",
        "web_url": "https://gitlab.jak.guru/public-libs/hermes",
        "name": "Html5 Boilerplate",
        "name_with_namespace": "Experimental / Html5 Boilerplate",
        "path": "html5-boilerplate",
        "path_with_namespace": "h5bp/html5-boilerplate",
        "issues_enabled": true,
        "merge_requests_enabled": true,
        "wiki_enabled": true,
        "jobs_enabled": true,
        "snippets_enabled": true,
        "created_at": "2016-04-05T21:40:50.169Z",
        "last_activity_at": "2016-04-06T16:52:08.432Z",
        "shared_runners_enabled": true,
        "creator_id": 1,
        "namespace": {
          "id": 5,
          "name": "Experimental",
          "path": "h5bp",
          "kind": "group"
        },
        "avatar_url": 'https://www.gravatar.com/avatar/XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
        "star_count": 1,
        "forks_count": 0,
        "open_issues_count": 3,
        "public_jobs": true,
        "shared_with_groups": [],
        "request_access_enabled": false
      }
    ]
  });
})
