'use strict'

const { test, trait } = use('Test/Suite')('Test Webhook Listing, Creation and Modification')

trait('Test/ApiClient')

test('Get Empty List of General Webhooks for Repository 9', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.get('/api/v1/repositories/9/webhooks').header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(200);
  // console.log(JSON.stringify(gr.body));
  gr.assertJSONSubset({"status":"SUCCESS","code":200,"body":{"total":0,"perPage":10,"page":1,"lastPage":0,"data":[]}});
});

test('Add a General Webhook for Repository 9', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.post('/api/v1/repositories/9/webhooks').send({
    name: 'General HTTPBin POST',
    active: true,
    url: 'http://httpbin.org/post',
    method: 'post',
    validate_ssl: false,
    auth_username: '',
    auth_password: '',
    headers: 'Content-Type:application/json',
    body_type: 'plain',
    body: '{"type":"general","user":"$DEPLOY_USERNAME","pass":"$DEPLOY_PASSWORD"}',
  }).header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(201);
  // console.log(JSON.stringify(gr.body));
  gr.assertJSONSubset({"status":"SUCCESS","code":201,"body":{"name":"General HTTPBin POST","active":true,"gitlab_repository_id":9,"repository_credentials_id":null,"url":"http://httpbin.org/post","method":"post","validate_ssl":false,"auth_username":null,"auth_password":null,"headers":"Content-Type:application/json","body_type":"plain","body":"{\"type\":\"general\",\"user\":\"$DEPLOY_USERNAME\",\"pass\":\"$DEPLOY_PASSWORD\"}","id":1}});
});

test('Get List of 1 General Webhook for Repository 9', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.get('/api/v1/repositories/9/webhooks').header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(200);
  // console.log(JSON.stringify(gr.body));
  gr.assertJSONSubset({"status":"SUCCESS","code":200,"body":{"total":1,"perPage":10,"page":1,"lastPage":1,"data":[{"id":1,"active":true,"name":"General HTTPBin POST","url":"http://httpbin.org/post","method":"post"}]}});
});

test('Get Empty List of Webhooks for Repository 9 Credentials 2', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.get('/api/v1/repositories/9/credentials/2/webhooks').header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(200);
  // console.log(JSON.stringify(gr.body));
  gr.assertJSONSubset({"status":"SUCCESS","code":200,"body":{"total":0,"perPage":10,"page":1,"lastPage":0,"data":[]}});
});

test('Add a Webhook for Repository 9 Credentials 2', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.post('/api/v1/repositories/9/credentials/2/webhooks').send({
    name: 'Credentials 2 HTTPBin POST',
    active: false,
    url: 'http://httpbin.org/post',
    method: 'post',
    validate_ssl: false,
    auth_username: '',
    auth_password: '',
    headers: 'Content-Type:application/json',
    body_type: 'plain',
    body: '{"type":"credentials","credentials":2,"user":"$DEPLOY_USERNAME","pass":"$DEPLOY_PASSWORD"}',
  }).header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(201);
  // console.log(JSON.stringify(gr.body));
  gr.assertJSONSubset({"status":"SUCCESS","code":201,"body":{"name":"Credentials 2 HTTPBin POST","active":false,"gitlab_repository_id":9,"repository_credentials_id":2,"url":"http://httpbin.org/post","method":"post","validate_ssl":false,"auth_username":null,"auth_password":null,"headers":"Content-Type:application/json","body_type":"plain","body":"{\"type\":\"credentials\",\"credentials\":2,\"user\":\"$DEPLOY_USERNAME\",\"pass\":\"$DEPLOY_PASSWORD\"}","id":2}});
});

test('Get List of 1 Webhook for Repository 9 Credentials 2', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.get('/api/v1/repositories/9/credentials/2/webhooks').header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(200);
  // console.log(JSON.stringify(gr.body));
  gr.assertJSONSubset({"status":"SUCCESS","code":200,"body":{"total":1,"perPage":10,"page":1,"lastPage":1,"data":[{"id":2,"active":false,"name":"Credentials 2 HTTPBin POST","url":"http://httpbin.org/post","method":"post"}]}});
});

test('Activate Webhook 2 for Repository 9 Credentials 2', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.post('/api/v1/repositories/9/credentials/2/webhooks/2/activation').send({
    state: true,
  }).header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(201);
  // console.log(JSON.stringify(gr.body));
  gr.assertJSONSubset({"status":"SUCCESS","code":201,"body":{"id":2,"name":"Credentials 2 HTTPBin POST","active":true,"gitlab_repository_id":9,"repository_credentials_id":2,"url":"http://httpbin.org/post","method":"post","validate_ssl":0,"auth_username":null,"auth_password":null,"headers":"Content-Type:application/json","body_type":"plain","body":"{\"type\":\"credentials\",\"credentials\":2,\"user\":\"$DEPLOY_USERNAME\",\"pass\":\"$DEPLOY_PASSWORD\"}"}});
});

test('Get Final List of Webhooks for Repository 9 Credentials 2', async ({ assert, client }) => {
  const response = await client.post('/api/v1/me').send({
    code: 'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
    state: 'randomvalue',
  }).end();
  response.assertStatus(201);
  assert.isString(response.body.body.token, 'JWT Created Successfully');
  const gr = await client.get('/api/v1/repositories/9/credentials/2/webhooks').header('Authorization', `Bearer ${response.body.body.token}`).end();
  gr.assertStatus(200);
  // console.log(JSON.stringify(gr.body));
  gr.assertJSONSubset({"status":"SUCCESS","code":200,"body":{"total":1,"perPage":10,"page":1,"lastPage":1,"data":[{"id":2,"active":true,"name":"Credentials 2 HTTPBin POST","url":"http://httpbin.org/post","method":"post"}]}});
});